#  tests for gtk3-3.24.31-h1c1119c_3 (this is a generated file);
print('===== testing package: gtk3-3.24.31-h1c1119c_3 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import gi
gi.require_version("Gtk", "3.0")
from gi.repository import GLib, Gtk
assert(3 == Gtk.get_major_version())

#  --- run_test.py (end) ---

print('===== gtk3-3.24.31-h1c1119c_3 OK =====');
